=======
Credits
=======

Development Lead
----------------

* Lev Rubel <l@datacorp.ee>

Contributors
------------

* Yaroslav Ulanovich <yul@datacorp.ee>
* BumagniyPacket <rly@datacorp.ee>
* aCLr <a.ch.clr@gmail.com>
